$regfile = "ATtiny13.DAT"
$crystal = 128000                                           'Reale Frequenz des internen 128kHz-Oszillators
$hwstack = 2                                                'aus Kochbuch_V3.pdf Seite 7
$swstack = 8                                                'aus Kochbuch_V3.pdf Seite 7
$framesize = 24                                             'aus Kochbuch_V3.pdf Seite 7
Config Portb = &B00010001                                   'Pinb.0 und Pinb.4 auf 'Ausgang', Rest auf 'Eingang' schalten
       Portb = &B11101110                                   'Pullups zuschalten, ausser fuer Pinb.0 und Pinb.4
Stop Adc                                                    'A/D-Wandler abschalten, um Strom zu sparen
Stop Ac                                                     'Analog-Komparator abschalten, um Strom zu sparen

Enable Interrupts

Do
  Portb.0 = 1
  Portb.4 = 0
  Wdtcr = &B11000000                                        'watchdog auf 16ms setzen
  Reset Watchdog
  Powerdown
  Portb.0 = 0
  Portb.4 = 1
  Wdtcr = &B11000111                                        'watchdog auf 2s setzen
  Reset Watchdog
  Powerdown
Loop

End



'  Blinker doppelt (blaue LED)                                     
'                                                                  
'  Schaltung:                                                      
'                                       IC = ATTINY13V             
'      C       LED      C                C = 100 F                
'   ---||---o--|<|--o---||---            R =  10 kOhm              
'  |        |       |        |         U_B =  1.0 ... 1.5 V        
'  |        -       -        |                                     
'  |     R | |   R | |       |                                     
'  |        -       -        |         Kondensator laden:          
'  |        |       |        |         u_c = u_0 * (1 - e^(-t/tau))
'  |    ----         ----    |                                     
'  |   |                 |   |         Zeitkonstante:              
'  |   |    ---- ----    |   |         tau = R * C                 
'  |   |  -| 1  U  8 |---o   |                                     
'  |   |  -| 2     7 |-  |   |         Aufladeniveau:              
'   ---|---| 3     6 |-  |   |         1 tau =  63 %               
'      o---| 4     5 |---|---          2 tau =  86 %               
'      |    ---------    |             3 tau =  95 %               
'      |                 |             4 tau =  98 %               
'     (-)               (+)            5 tau = 100 %               


' Quelle: Datenblatt doc2535.pdf

' 1. Pin Configurations
' Figure 1-1. Pinout ATtiny13/ATtiny13V
'                                  ---- ----
'   (PCINT5/RESET/ADC0/dW) PB5   -| 1  U  8 |-   VCC
'   (PCINT3/CLKI/ADC3) PB3       -| 2     7 |-   PB2 (SCK/ADC1/T0/PCINT2)
'   (PCINT4/ADC2) PB4            -| 3     6 |-   PB1 (MISO/AIN1/OC0B/INT0/PCINT1)
'   GND                          -| 4     5 |-   PB0 (MOSI/AIN0/OC0A/PCINT0)
'                                  ---------


' 10.4.2 PORTB  Port B Data Register

' Bit           || 7 | 6 |   5    |   4    |   3    |   2    |   1    |   0    ||
'               ||  |  | PORTB5 | PORTB4 | PORTB3 | PORTB2 | PORTB1 | PORTB0 || PORTB
' Read/Write    || R | R |  R/W   |  R/W   |  R/W   |  R/W   |  R/W   |  R/W   ||
' Initial Value || 0 | 0 |   0    |   0    |   0    |   0    |   0    |   0    ||


' 10.2.1 Configuring the Pin
' If PORTxn is written logic one when the pin is configured as an input pin, the pull-up resistor is
' activated. To switch the pull-up resistor off, PORTxn has to be written logic zero or the pin has to
' be configured as an output pin.


' Quelle: Datenblatt: doc8126.pdf

'  Name   || Bit 7 | Bit 6 | Bit 5 | Bit 4 | Bit 3 | Bit 2 | Bit 1 | Bit 0 |
'  WDTCR: || WDTIF | WDTIE | WDP3  | WDCE  |  WDE  | WDP2  | WDP1  | WDP0  |

'  Bit 7 - WDTIF: Watchdog Timer Interrupt Flag
'          setzt man es auf "1" wird das Flag gelscht
'  Bit 6 - WDTIE: Watchdog Timer Interrupt Enable
'  Bit 4 - WDCE: Watchdog Change Enable
'  Bit 3 - WDE: Watchdog System Reset Enable
'  Bit 5, 2:0 - WDP[3:0]: Watchdog Timer Prescaler 3, 2, 1 and 0


'  Table 8-1. Watchdog Timer Configuration
'  WDTON | WDE | WDTIE | Mode                              | Action on Time-out
'     1     0      0     Stopped                             None
'     1     0      1     Interrupt Mode                      Interrupt
'     1     1      0     System Reset Mode                   Reset
'     1     1      1     Interrupt and System Reset Mode     Interrupt, then go to System Reset Mode
'     0     x      x     System Reset Mode                   Reset


'  Table 8-2. Watchdog Timer Prescale Select
'  WDP3 | WDP2 | WDP1 | WDP0  | Typical Time-out at VCC = 5.0V
'    0     0      0      0        16 ms
'    0     0      0      1        32 ms
'    0     0      1      0        64 ms
'    0     0      1      1        0.125 s
'    0     1      0      0        0.25 s
'    0     1      0      1        0.5 s
'    0     1      1      0        1.0 s
'    0     1      1      1        2.0 s
'    1     0      0      0        4.0 s
'    1     0      0      1        8.0 s



'  Wdtcr = &B1100 0000                                 'watchdog auf 16ms setzen
'  Wdtcr = &B1100 0001                                 'watchdog auf 32ms setzen
'  Wdtcr = &B1100 0010                                 'watchdog auf 64ms setzen
'  Wdtcr = &B1100 0011                                 'watchdog auf 0.125s setzen
'  Wdtcr = &B1100 0100                                 'watchdog auf 0.25s setzen
'  Wdtcr = &B1100 0101                                 'watchdog auf 0.5s setzen
'  Wdtcr = &B1100 0110                                 'watchdog auf 1  s setzen
'  Wdtcr = &B1100 0111                                 'watchdog auf 2  s setzen
'  Wdtcr = &B1110 0000                                 'watchdog auf 4  s setzen
'  Wdtcr = &B1110 0001                                 'watchdog auf 8  s setzen